KhipuStartOperationOptions class

Constructors

KhipuStartOperationOptions({required String operationId, String? locale, String? title, String? titleImageUrl, bool? skipExitPage, bool? skipExitSuccessPage, bool? showFooter, bool? showPaymentDetails, String? theme, KhipuColors? colors})

Properties

colors KhipuColors?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
locale String?
getter/setter pair
operationId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showFooter bool?
getter/setter pair
getter/setter pair
showPaymentDetails bool?
getter/setter pair
skipExitPage bool?
getter/setter pair
skipExitSuccessPage bool?
getter/setter pair
theme String?
getter/setter pair
title String?
getter/setter pair
titleImageUrl String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited